@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -56,8 +56,13 @@ class SelectedMethodWgt(QtGui.QWidget):
         layout.addWidget(self.MethodWidget)
 
         QtGui.QIcon.setThemeName('Calculate')
-        self.setWindowIcon(QtGui.QIcon \
-                        ('/usr/share/pixmaps/calculate-console-online.png'))
+        icon = QtGui.QIcon.fromTheme('cl-console-gui-%s'%self.method.replace("_","-"))
+        if icon.isNull():
+            icon = QtGui.QIcon.fromTheme('calculate-%s'%self.method.replace("_","-"))
+
+        self.setWindowIcon(icon)
+        QtGui.QApplication.setWindowIcon(icon)
+
         conf_path = self.VarsGui.Get('cl_gui_config_path')
         homePath = self.VarsGui.Get('ur_home_path')
         self.user_config = conf_path.replace("~",homePath)
@@ -335,7 +340,7 @@ class ToolTabWidget(QtGui.QTabWidget):
                             stop: 0.5 #E1E1E1, stop: 1.0 #DDDDDD);}
                             ''')
         self.setWindowIcon(QtGui.QIcon \
-                          ('/usr/share/pixmaps/calculate-console-offline.png'))
+                          ('/usr/share/pixmaps/calculate-console-offline.svg'))
 
         self.show()
         self.app.processEvents()
@@ -378,12 +383,12 @@ class ToolTabWidget(QtGui.QTabWidget):
 
         if self.connect_dict:
             self.setWindowIcon(QtGui.QIcon \
-                        ('/usr/share/pixmaps/calculate-console-online.png'))
+                        ('/usr/share/pixmaps/calculate-console-online.svg'))
             if hasattr(self, 'tray'):
                 self.tray.set_icon(True)
         else:
             self.setWindowIcon(QtGui.QIcon \
-                         ('/usr/share/pixmaps/calculate-console-offline.png'))
+                         ('/usr/share/pixmaps/calculate-console-offline.svg'))
             if hasattr(self, 'tray'):
                 self.tray.set_icon(False)
 
